/*
 *
 *
 *    config_AA0.h
 *
 *    Configuration options for reading CW data from Arduino A/D.
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2014-2017 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *
 *
 */

//
//  REQUIRED: The center frequency (Hz) of the tone tetector.
//
#define CW_FREQ (700.0)

//
//  REQUIRED: Tone decoder algorithm selection.
//
//  Set this to 'true' to enable LM567 emulation in the firmware.
//  This will still read audio data from the A0 pin, but the
//  detection algorithm will emulate an LM567 chip in software.
//
//  Set this to 'false' to use a delay-line-product algorithm.
//
//  The 567 emulation performance is a few dB better when trying
//  to detect a tone buried in wideband Gaussian noise.
//
#define EMULATE_LM567 true

//
//  OPTIONAL: enable tuning indicator
//
//  If using the 567 emulation, setting these will enable a trigraph
//  of LEDs on the corresponding pins, which can be used as a tuning
//  indicator.
//
#define CW_TRIGRAPH_LEFT (5)
#define CW_TRIGRAPH_CENTER (6)
#define CW_TRIGRAPH_RIGHT (7)

//
//  ADVANCECD: 567 PLL control voltage integration window
//
//  This sets the integration window for PLL offset measurements,
//  measured in msec. This is used by the trigraph, among other things.
//
#define EM567_OFFSET_INT (100)

//
//  ADVANCED: Define the audio sampling rate.
//
//  Don't change this unless you know exactly what you are doing.  The
//  567 algorithm in particular cannot function if this value is too low.
//
#define CW_SAMPLE_RATE (8000)

//
//  ADVANCED: DC offset on A0 pin
//
//  Define the zero-volts value to be read from the A/D.  If your
//  hardware has a perfectly centered DC offset (using a high-
//  quality voltage divider, etc.), just leave this at 127.  If
//  you have a larger DC offset, you can change this *slightly*
//  to compensate.
//
#define ANALOG_DC_OFFSET (127)

//
//  ADVANCED: these control certain PLL settings when EMULATE_LM567 is
//  set to 'true'.
//
//  Setting any of these value to zero will cause a reasonable default
//  value to be computed at runtime and used.  These values should be
//  near-optimal when using the default sampling rate of 8kHz.
//
//  Do not change any of these settings unless you know what you are doing.
//  These values (96-32-1) work well for a sample rate of 8000Hz.
//
#define EM567_OUTPUT_INTEGRATOR 96
#define EM567_LOOP_INTEGRATOR 32
#define EM567_LOOP_VCO_LIMIT 1

// EOF:
