/*
 *
 *
 *    minmax.h
 *
 *    Min/max tracking.
 *
 *    Copyright (C) 2016 by Matt Roberts.
 *    License: GNU GPL3 (www.gnu.org)
 *
 *
 */

#ifndef __KK5JY_MINMAXTRACK_H
#define __KK5JY_MINMAXTRACK_H

#ifdef __linux__
// includes here
#endif

namespace KK5JY {
	namespace DSP {
		/*
		 *
		 *   class MinMaxTrack<T>
		 *
		 */
		template <typename sample_t = double>
		class MinMaxTrack {
			private:
				// the length of the window
				const size_t _length;
				sample_t _min, _max;
				size_t _ct;

			public:
				MinMaxTrack(size_t length) : _length(length), _min(0), _max(0), _ct(0) {
					// nop
				}
			private: // disallowed ctors
				MinMaxTrack(const MinMaxTrack&);

			public:
				size_t size(void) const { return _length; }
				sample_t minimum(void) const { return _min; }
				sample_t maximum(void) const { return _max; }

			public:
				bool run(const sample_t s);
		};


		template <typename sample_t>
		inline bool MinMaxTrack<sample_t>::run(const sample_t s) {
			if (_ct++ == 0) {
				_min = _max = s;
			} else {
				if (s > _max) _max = s;
				if (s < _min) _min = s;
			}

			if (_ct == _length) {
				_ct = 0;
			}

			return _ct == 0;
		}
	}
}

#endif
