/*
 *
 *
 *    nlimits.h
 *
 *    Normalized numeric limits.
 *
 *    Copyright (C) 2016 by Matt Roberts.
 *    License: GNU GPL3 (www.gnu.org)
 *
 *
 */

#ifndef __KK5JY_NLIMITS_H
#define __KK5JY_NLIMITS_H

#ifdef __linux__
#include <limits>
#endif

namespace KK5JY {
	namespace DSP {
		// normalization limits
		template<typename sample_t>
		struct norm_limits {
			const static sample_t maximum;
			const static sample_t minimum;
			const static bool is_signed;
		};

		#ifdef __linux__
		template<typename sample_t>
		const sample_t norm_limits<sample_t>::maximum = std::numeric_limits<sample_t>::max();

		template<typename sample_t>
		const sample_t norm_limits<sample_t>::minimum = std::numeric_limits<sample_t>::min();

		template<typename sample_t>
		const bool norm_limits<sample_t>::is_signed = std::numeric_limits<sample_t>::is_signed;
		#else
		// int8
		template<>
		const int8_t norm_limits<int8_t>::maximum = 127;

		template<>
		const int8_t norm_limits<int8_t>::minimum = -128;

		template<>
		const bool norm_limits<int8_t>::is_signed = true;

		// uint8
		template<>
		const uint8_t norm_limits<uint8_t>::maximum = 255;

		template<>
		const uint8_t norm_limits<uint8_t>::minimum = 0;

		template<>
		const bool norm_limits<uint8_t>::is_signed = false;

		// int16
		template<>
		const int16_t norm_limits<int16_t>::maximum = 32767;

		template<>
		const int16_t norm_limits<int16_t>::minimum = -32768;

		template<>
		const bool norm_limits<int16_t>::is_signed = true;

		// uint16
		template<>
		const uint16_t norm_limits<uint16_t>::maximum = 65535;

		template<>
		const uint16_t norm_limits<uint16_t>::minimum = 0;

		template<>
		const bool norm_limits<uint16_t>::is_signed = false;

		// int32
		template<>
		const int32_t norm_limits<int32_t>::maximum = 2147483647L;

		template<>
		const int32_t norm_limits<int32_t>::minimum = -2147483648L;

		template<>
		const bool norm_limits<int32_t>::is_signed = true;

		// uint32
		template<>
		const uint32_t norm_limits<uint32_t>::maximum = 4294967295UL;

		template<>
		const uint32_t norm_limits<uint32_t>::minimum = 0;

		template<>
		const bool norm_limits<uint32_t>::is_signed = false;
		#endif

		//
		//  floating limits (-1, 1)
		//
		template<>
		const float norm_limits<float>::maximum = 1.0;

		template<>
		const float norm_limits<float>::minimum = 1.0;

		template<>
		const double norm_limits<double>::maximum = 1.0;

		template<>
		const double norm_limits<double>::minimum = 1.0;
	}
}

#endif
